import os
import requests
import argparse
import time
from watchdog.observers import Observer
from watchdog.events import FileSystemEventHandler


class LogHandler(FileSystemEventHandler):
    def __init__(
        self,
        log_file_path,
        service_name,
        api_token,
    ):
        self.log_file_path = log_file_path
        self.service_name = service_name
        self.api_token = api_token

        # Если файл существует, начинаем отслеживать его
        # с текущего конца файла. Если файла нет, начинаем с нуля.
        self.position = (
            os.path.getsize(log_file_path)
            if os.path.isfile(log_file_path)
            else 0
        )

    def send_log(self, string_log):
        headers = {"ApiToken": self.api_token}
        log_entry = {
            "service_name": self.service_name,
            "message": string_log,
        }
        try:
            requests.post(
                "https://observer.goltsev.net/api/v1/sendlog/",
                headers=headers,
                data=log_entry,
            )
        except requests.RequestException as e:
            print(f"Failed to send log: {e}")

    def on_modified(self, event):
        if os.path.realpath(event.src_path) == os.path.realpath(
            self.log_file_path
        ):
            with open(self.log_file_path) as file:
                file.seek(
                    self.position
                )  # Перейти к последней запомненной позиции
                log = file.read()  # Читать только новый участок в файле
                self.position = (
                    file.tell()
                )  # Запомнить позицию для следующего чтения
            self.send_log(log)


if __name__ == "__main__":
    parser = argparse.ArgumentParser(description="Send log data.")
    parser.add_argument(
        "-l",
        "--log",
        default="/var/log/auth.log",
        help="Path to the log file.",
    )
    parser.add_argument("-s", "--service", required=True, help="Service name.")
    parser.add_argument("-t", "--token", required=True, help="API token.")
    args = parser.parse_args()

    observer = Observer()
    observer.schedule(
        LogHandler(args.log, args.service, args.token),
        path=os.path.dirname(args.log),
        recursive=False,
    )
    observer.start()

    print("observer start.")
    try:
        while True:
            time.sleep(1)
    except KeyboardInterrupt:
        observer.stop()

    observer.join()
